==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/analysisservices/kotlin/inputs/ServerAdministratorsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.analysisservices.kotlin.inputs

import com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * An array of administrator user identities.
 * @property members An array of administrator user identities.
 */
public data class ServerAdministratorsArgs(
    public val members: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs> {
    override fun toJava(): com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs =
        com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs.builder()
            .members(members?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ServerAdministratorsArgs].
 */
@PulumiTagMarker
public class ServerAdministratorsArgsBuilder internal constructor() {
    private var members: Output<List<String>>? = null

    /**
     * @param value An array of administrator user identities.
     */
    @JvmName("aplqpmvqkwbvkhkn")
    public suspend fun members(`value`: Output<List<String>>) {
        this.members = value
    }

    @JvmName("naresuwdnkkiviiy")
    public suspend fun members(vararg values: Output<String>) {
        this.members = Output.all(values.asList())
    }

    /**
     * @param values An array of administrator user identities.
     */
    @JvmName("yofdlujcnycfjsea")
    public suspend fun members(values: List<Output<String>>) {
        this.members = Output.all(values)
    }

    /**
     * @param value An array of administrator user identities.
     */
    @JvmName("yjdocfsiyanxubad")
    public suspend fun members(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.members = mapped
    }

    /**
     * @param values An array of administrator user identities.
     */
    @JvmName("khujwaigjxieyvuk")
    public suspend fun members(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.members = mapped
    }

    internal fun build(): ServerAdministratorsArgs = ServerAdministratorsArgs(
        members = members,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/analysisservices/kotlin/inputs/ServerAdministratorsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.analysisservices.kotlin.inputs

import com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * An array of administrator user identities.
 * @property members An array of administrator user identities.
 */
public data class ServerAdministratorsArgs(
    public val members: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs> {
    override fun toJava(): com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs =
        com.pulumi.azurenative.analysisservices.inputs.ServerAdministratorsArgs.builder()
            .members(members?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [ServerAdministratorsArgs].
 */
@PulumiTagMarker
public class ServerAdministratorsArgsBuilder internal constructor() {
    private var members: Output<List<String>>? = null

    /**
     * @param value An array of administrator user identities.
     */
    @JvmName("ywbbedyntdbixoga")
    public suspend fun members(`value`: Output<List<String>>) {
        this.members = value
    }

    @JvmName("cjyqmtjbosegfwlb")
    public suspend fun members(vararg values: Output<String>) {
        this.members = Output.all(values.asList())
    }

    /**
     * @param values An array of administrator user identities.
     */
    @JvmName("oqxomtbdbkocpada")
    public suspend fun members(values: List<Output<String>>) {
        this.members = Output.all(values)
    }

    /**
     * @param value An array of administrator user identities.
     */
    @JvmName("ulpsrimpnrvpdbje")
    public suspend fun members(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.members = mapped
    }

    /**
     * @param values An array of administrator user identities.
     */
    @JvmName("vdmqmwclmkcriwgg")
    public suspend fun members(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.members = mapped
    }

    internal fun build(): ServerAdministratorsArgs = ServerAdministratorsArgs(
        members = members,
    )
}
